@@ -9,18 +9,21 @@ class Cache:
     CACHE_NAME: str = "cache.pkl"
 
     @staticmethod
-    def cache(obj):
+    def cache(obj, path: str | None = None):
 
         cache = os.path.join(Cache.CACHE_DIRECTORY, Cache.CACHE_NAME)
 
         current_cache = {}
 
+        if not path:
+            path = os.getcwd()
+
         if (os.path.exists(cache)):
             with open(cache, "rb") as file:
                 current_cache = pickle.load(file)
 
         obj["messages"] = obj["messages"][:-1]
-        current_cache[os.getcwd()] = obj
+        current_cache[path] = obj
 
         with open(cache, "wb") as file:
             pickle.dump(current_cache, file)
@@ -39,4 +42,6 @@ class Cache:
 
     @staticmethod
     def _clear_cache():
-        os.remove(os.path.join(Cache.CACHE_DIRECTORY, Cache.CACHE_NAME))
+        cache = os.path.join(Cache.CACHE_DIRECTORY, Cache.CACHE_NAME)
+        if os.path.exists(cache):
+            os.remove(cache)
